==> mk-livestatus-1.1.3.tar.gz: mk-livestatus-1.1.3/src/OffsetIntColumn.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2010             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
// 
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
// 
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef OffsetIntColumn_h
#define OffsetIntColumn_h

#include "config.h"

#include <stdlib.h>
#include "IntColumn.h"

class OffsetIntColumn : public IntColumn
{
    int _offset;
public:
    OffsetIntColumn(string name, string description, int offset, int indirect_offset = -1) 
	: IntColumn(name, description, indirect_offset), _offset(offset) {};
    int32_t getValue(void *data);
protected:
    int offset() { return _offset; };
};


#endif // OffsetIntColumn_h

==> mk-livestatus-1.1.8.tar.gz: mk-livestatus-1.1.8/src/OffsetIntColumn.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2010             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef OffsetIntColumn_h
#define OffsetIntColumn_h

#include "config.h"

#include <stdlib.h>
#include "IntColumn.h"

class OffsetIntColumn : public IntColumn
{
    int _offset;
public:
    OffsetIntColumn(string name, string description, int offset, int indirect_offset = -1) 
	: IntColumn(name, description, indirect_offset), _offset(offset) {};
    int32_t getValue(void *data, Query *);
protected:
    int offset() { return _offset; };
};


#endif // OffsetIntColumn_h
